function P = normal(v);

%_____________________________________________________________________________
% NORMAL.M
% Argument: v (quantiles) 
% This function computes the standard normal distribution function 
% uses a polynomial approximation with error term < 7.5e-8
% Reference: Hand. of Math. Funct. Abramowitz and Segun, formula 26.2.17 
%_____________________________________________________________________________

for j=1:length(v); 

x=v(j); 
if x==0,
	P(j)=.5;
elseif x > 0,
	z=exp(-x^2*.5)/sqrt(2*pi);
	t=x/x/(1+.2316419*x);
	b1=.319381530;
	b2=-.356563782;
	b3=1.781477937;
	b4=-1.821255978;
	b5=1.330274429;
	P(j)=1-z*(b1*t+b2*t^2+b3*t^3+b4*t^4+b5*t^5);
elseif x < 0,
	x=-x;
	z=exp(-x^2*.5)/sqrt(2*pi);
        t=x/x/(1+.2316419*x);
        b1=.319381530;
        b2=-.356563782;
        b3=1.781477937;
        b4=-1.821255978;
        b5=1.330274429;
        p=1-z*(b1*t+b2*t^2+b3*t^3+b4*t^4+b5*t^5);
	P(j)=1-p;
end;

end;
